[![PyPI](https://img.shields.io/pypi/v/blast2galaxy?color=blue&label=PyPI.org)](https://pypi.org/project/blast2galaxy/)
![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/IPK-BIT/blast2galaxy?color=blue&label=Github)



[![Python](https://img.shields.io/pypi/pyversions/blast2galaxy.svg?color=green)](https://badge.fury.io/py/blast2galaxy)
[![Documentation Status](https://readthedocs.org/projects/blast2galaxy/badge/?version=latest)](https://blast2galaxy.readthedocs.io/en/latest/?badge=latest)
[![PyPI Downloads](https://img.shields.io/pypi/dm/blast2galaxy.svg?label=PyPI%20downloads)](https://pypi.org/project/blast2galaxy/)
![License](https://img.shields.io/github/license/IPK-BIT/divbrowse)


# blast2galaxy


## About

A Python package providing a CLI and API to perform BLAST+ and DIAMOND queries against public or private Galaxy servers 

## Documentation

See http://blast2galaxy.readthedocs.io